==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescription } from "./WebColumnVisibilityChangingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "Unknown");
            a.item("NewValue", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebColumnVisibilityChangingEventArgsDetail", () => new WebColumnVisibilityChangingEventArgsDetailDescription());
            a.ac("WebColumnVisibilityChangingEventArgsDetail", WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescription } from "./WebColumnVisibilityChangingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "Unknown");
            a.item("NewValue", "Boolean");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebColumnVisibilityChangingEventArgsDetail", () => new WebColumnVisibilityChangingEventArgsDetailDescription());
            a.ad("WebColumnVisibilityChangingEventArgsDetail", WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata;
})();
